@@ -23,14 +23,14 @@ function(y1vec, y2vec, x1Matr, x2Matr, eststage1, eststage2, eststage2sigma, wei
       s2=s2+t.c*weights[i]*drop(dLambdadSM(x1Matr[i,],eststage1$coeff))*(x1Matr[i,])
     }
     else {
-      s1=s1+( x2Matr[i,1:dim(x2Matr)[2]-1] )%*%t(x1Matr[i,])*eststage2[dim(x2Matr)[2]]*weights[i]*drop(dLambdadSM(x1Matr[i,],eststage1$coeff))/eststage2sigma
-      s2=s2+(x2Matr[i,dim(x2Matr)[2]]*eststage2[dim(x2Matr)[2]])*weights[i]*dLambdadSM(x1Matr[i,],eststage1$coeff)/eststage2sigma*x1Matr[i,]
-    }
+      s1=s1+(x2Matr[i,1:dim(x2Matr)[2]-1])%*%t(x1Matr[i,])*eststage2[dim(x2Matr)[2]]*weights[i]*drop(dLambdadSM(x1Matr[i,],eststage1$coeff))/eststage2sigma
+      s2=s2+(x2Matr[i,dim(x2Matr)[2]]*eststage2[dim(x2Matr)[2]])*weights[i]*c(dLambdadSM(x1Matr[i,],eststage1$coeff))/eststage2sigma*x1Matr[i,]
+      }
   }
-  xdx=rbind(s1,s2)
-  term2=xdx%*%vcov(eststage1)%*%t(xdx)  
+  xdx <- rbind(s1,s2)
+  term2 <- xdx%*%vcov(eststage1)%*%t(xdx)  
   
-  result=(solve(MmatrM(x2Matr,y2vec,eststage2,eststage2sigma,t.c,weights))%*%   # asymptotic variance for Heckman-M-estimator
+  result <- (solve(MmatrM(x2Matr,y2vec,eststage2,eststage2sigma,t.c,weights))%*%   # asymptotic variance for Heckman-M-estimator
     (sumheck+term2)%*%solve(MmatrM(x2Matr,y2vec,eststage2,eststage2sigma,t.c,weights)))
   return(result)
 }
